import { useForm } from 'react-hook-form';
import { yupResolver } from '@hookform/resolvers/yup';
import { User, Phone, Mail, UserCircle } from 'lucide-react';
import { Input } from '../ui/Input';
import { Button } from '../ui/Button';
import { userSchema, UserFormData } from '../../utils/validationSchemas';

interface UserFormProps {
    initialData?: Partial<UserFormData>;
    onSubmit: (data: UserFormData) => void;
    onCancel: () => void;
    loading?: boolean;
    isEdit?: boolean;
}

export const UserForm = ({
    initialData,
    onSubmit,
    onCancel,
    loading = false,
    isEdit = false
}: UserFormProps) => {
    const {
        register,
        handleSubmit,
        formState: { errors, isValid },
    } = useForm<UserFormData>({
        resolver: yupResolver(userSchema),
        mode: 'onChange',
        defaultValues: initialData,
    });

    return (
        <div className="card p-6">
            <div className="mb-6">
                <h2 className="text-xl font-bold text-gray-900 dark:text-gray-100">
                    {isEdit ? 'ویرایش کاربر' : 'افزودن کاربر جدید'}
                </h2>
                <p className="text-gray-600 dark:text-gray-400 mt-1">
                    اطلاعات کاربر را وارد کنید
                </p>
            </div>

            <form onSubmit={handleSubmit(onSubmit)} className="space-y-6">
                <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                    <Input
                        label="نام و نام خانوادگی"
                        placeholder="علی احمدی"
                        icon={User}
                        error={errors.name?.message}
                        {...register('name')}
                    />

                    <Input
                        label="ایمیل"
                        type="email"
                        placeholder="ali@example.com"
                        icon={Mail}
                        error={errors.email?.message}
                        {...register('email')}
                    />

                    <Input
                        label="شماره تلفن"
                        type="tel"
                        placeholder="09123456789"
                        icon={Phone}
                        error={errors.phone?.message}
                        {...register('phone')}
                    />

                    <div className="space-y-1">
                        <label className="block text-sm font-medium text-gray-700 dark:text-gray-300">
                            نقش
                        </label>
                        <div className="relative">
                            <div className="absolute inset-y-0 right-0 pr-3 flex items-center pointer-events-none">
                                <UserCircle className="h-5 w-5 text-gray-400" />
                            </div>
                            <select
                                className={`input pr-10 ${errors.role ? 'border-red-500 dark:border-red-500 focus:ring-red-500' : ''
                                    }`}
                                {...register('role')}
                            >
                                <option value="">انتخاب کنید</option>
                                <option value="کاربر">کاربر</option>
                                <option value="مدیر">مدیر</option>
                                <option value="ادمین">ادمین</option>
                            </select>
                        </div>
                        {errors.role && (
                            <p className="text-sm text-red-600 dark:text-red-400">
                                {errors.role.message}
                            </p>
                        )}
                    </div>
                </div>

                {!isEdit && (
                    <Input
                        label="رمز عبور"
                        type="password"
                        placeholder="حداقل ۶ کاراکتر"
                        error={errors.password?.message}
                        {...register('password')}
                    />
                )}

                <div className="flex items-center justify-end space-x-4 pt-6 border-t border-gray-200 dark:border-gray-700">
                    <Button
                        type="button"
                        variant="secondary"
                        onClick={onCancel}
                        disabled={loading}
                    >
                        انصراف
                    </Button>
                    <Button
                        type="submit"
                        loading={loading}
                        disabled={!isValid}
                    >
                        {isEdit ? 'ویرایش' : 'افزودن'}
                    </Button>
                </div>
            </form>
        </div>
    );
}; 