import { useState } from 'react';
import { NavLink } from 'react-router-dom';
import {
    LayoutDashboard,
    Users,
    ShoppingBag,
    ShoppingCart,
    FileText,
    Bell,
    Menu,
    X,
    ChevronDown
} from 'lucide-react';
import { useAuth } from '../../contexts/AuthContext';
import { PermissionWrapper } from '../common/PermissionWrapper';
import { MenuItem } from '../../types';

const menuItems: MenuItem[] = [
    {
        id: 'dashboard',
        label: 'داشبورد',
        icon: LayoutDashboard,
        path: '/',
    },
    {
        id: 'users',
        label: 'کاربران',
        icon: Users,
        path: '/users',
        permission: 10,
    },
    {
        id: 'products',
        label: 'محصولات',
        icon: ShoppingBag,
        path: '/products',
        permission: 15,
    },
    {
        id: 'orders',
        label: 'سفارشات',
        icon: ShoppingCart,
        path: '/orders',
        permission: 20,
    },
    {
        id: 'reports',
        label: 'گزارش‌ها',
        icon: FileText,
        path: '/reports',
        permission: 25,
    },
    {
        id: 'notifications',
        label: 'اعلانات',
        icon: Bell,
        path: '/notifications',
        permission: 30,
    },
];

interface SidebarProps {
    isOpen: boolean;
    onClose: () => void;
}

export const Sidebar = ({ isOpen, onClose }: SidebarProps) => {
    const { user } = useAuth();
    const [expandedItems, setExpandedItems] = useState<string[]>([]);

    const toggleExpanded = (itemId: string) => {
        setExpandedItems(prev =>
            prev.includes(itemId)
                ? prev.filter(id => id !== itemId)
                : [...prev, itemId]
        );
    };

    const renderMenuItem = (item: MenuItem) => {
        const hasChildren = item.children && item.children.length > 0;
        const isExpanded = expandedItems.includes(item.id);

        const menuContent = (
            <>
                <div
                    className={`flex items-center justify-between px-4 py-3 text-gray-700 dark:text-gray-300 hover:bg-gray-100 dark:hover:bg-gray-700 rounded-lg transition-colors ${hasChildren ? 'cursor-pointer' : ''
                        }`}
                    onClick={hasChildren ? () => toggleExpanded(item.id) : undefined}
                >
                    <div className="flex items-center">
                        <item.icon className="h-5 w-5 ml-3" />
                        <span className="font-medium">{item.label}</span>
                    </div>
                    {hasChildren && (
                        <ChevronDown
                            className={`h-4 w-4 transition-transform ${isExpanded ? 'rotate-180' : ''}`}
                        />
                    )}
                </div>

                {hasChildren && isExpanded && (
                    <div className="mr-8 mt-1 space-y-1">
                        {item.children?.map(child => (
                            <div key={child.id}>
                                {child.permission ? (
                                    <PermissionWrapper permission={child.permission}>
                                        <NavLink
                                            to={child.path}
                                            className={({ isActive }) =>
                                                `block px-4 py-2 text-sm text-gray-600 dark:text-gray-400 hover:bg-gray-100 dark:hover:bg-gray-700 rounded-lg transition-colors ${isActive ? 'bg-primary-100 dark:bg-primary-900 text-primary-700 dark:text-primary-300' : ''
                                                }`
                                            }
                                            onClick={onClose}
                                        >
                                            {child.label}
                                        </NavLink>
                                    </PermissionWrapper>
                                ) : (
                                    <NavLink
                                        to={child.path}
                                        className={({ isActive }) =>
                                            `block px-4 py-2 text-sm text-gray-600 dark:text-gray-400 hover:bg-gray-100 dark:hover:bg-gray-700 rounded-lg transition-colors ${isActive ? 'bg-primary-100 dark:bg-primary-900 text-primary-700 dark:text-primary-300' : ''
                                            }`
                                        }
                                        onClick={onClose}
                                    >
                                        {child.label}
                                    </NavLink>
                                )}
                            </div>
                        ))}
                    </div>
                )}
            </>
        );

        if (!hasChildren) {
            return (
                <NavLink
                    to={item.path}
                    className={({ isActive }) =>
                        `flex items-center px-4 py-3 rounded-lg transition-colors ${isActive
                            ? 'text-primary-700 dark:text-primary-300 bg-primary-100 dark:bg-primary-900'
                            : 'text-gray-700 dark:text-gray-300 hover:bg-gray-100 dark:hover:bg-gray-700'
                        }`
                    }
                    onClick={onClose}
                >
                    <item.icon className="h-5 w-5 ml-3" />
                    <span className="font-medium">{item.label}</span>
                </NavLink>
            );
        }

        return <div>{menuContent}</div>;
    };

    return (
        <>
            {isOpen && (
                <div
                    className="fixed inset-0 bg-black bg-opacity-50 z-40 lg:hidden"
                    onClick={onClose}
                />
            )}

            <div className={`
        fixed top-0 right-0 h-full w-64 bg-white dark:bg-gray-800 shadow-lg z-50 transform transition-transform duration-300 ease-in-out
        ${isOpen ? 'translate-x-0' : 'translate-x-full'}
        lg:relative lg:translate-x-0
      `}>
                <div className="flex items-center justify-between p-4 border-b border-gray-200 dark:border-gray-700">
                    <div className="flex items-center">
                        <div className="w-8 h-8 bg-primary-600 rounded-lg flex items-center justify-center">
                            <LayoutDashboard className="h-5 w-5 text-white" />
                        </div>
                        <span className="mr-3 text-xl font-bold text-gray-900 dark:text-gray-100">
                            پنل مدیریت
                        </span>
                    </div>
                    <button
                        onClick={onClose}
                        className="p-1 rounded-lg hover:bg-gray-100 dark:hover:bg-gray-700 lg:hidden"
                    >
                        <X className="h-5 w-5" />
                    </button>
                </div>

                <div className="p-4">
                    <div className="flex items-center mb-6 p-3 bg-gray-50 dark:bg-gray-700 rounded-lg">
                        <div className="w-10 h-10 bg-primary-600 rounded-full flex items-center justify-center">
                            <span className="text-white font-medium">
                                {user?.name?.charAt(0) || 'A'}
                            </span>
                        </div>
                        <div className="mr-3">
                            <p className="text-sm font-medium text-gray-900 dark:text-gray-100">
                                {user?.name || 'کاربر'}
                            </p>
                            <p className="text-xs text-gray-500 dark:text-gray-400">
                                {user?.role || 'مدیر'}
                            </p>
                        </div>
                    </div>

                    <nav className="space-y-2">
                        {menuItems.map(item => (
                            <div key={item.id}>
                                {item.permission ? (
                                    <PermissionWrapper permission={item.permission}>
                                        {renderMenuItem(item)}
                                    </PermissionWrapper>
                                ) : (
                                    renderMenuItem(item)
                                )}
                            </div>
                        ))}
                    </nav>
                </div>
            </div>
        </>
    );
}; 